@@ -19,9 +19,5 @@ from .image import Image
 from .observation import Observation
 from .observations import Observations
 
-
-def load(photfile):
-    return Observation(photfile)
-
 from pkg_resources import get_distribution
 __version__ = get_distribution('prose').version
