@@ -51,7 +51,7 @@ def cutouts(image, stars, size=15):
         stars_tbl = Table(
             data=np.array([stars[0][0], stars[0][1]]),
             names=["x", "y"])
-        stars = extract_stars(NDData(data=image), stars_tbl, size=size)
+        stars = ([0], [extract_stars(NDData(data=image), stars_tbl, size=size)])
         return stars
 
 
@@ -110,6 +110,7 @@ class Cutouts(Block):
     |write| 
     - ``Image.cutouts``: cutouts images
     - ``Image.cutouts_idxs``: indexes of stars_coords corresponding to each cutout 
+    - ``Image.stars_coords`` if ``clean`` is ``True``
 
     Cutouts are sometimes called "imagette" and represent small square portions of the image centered on specific points.
 
@@ -118,13 +119,19 @@ class Cutouts(Block):
     size : int, optional
        square side length of the cutout in pixel, by default 21
     """
-    @register_args
-    def __init__(self, size=21, **kwargs):
-        super().__init__(**kwargs)
+    
+    def __init__(self, size=21, clean=True, name=None):
+        super().__init__(name=name)
         self.size = size
+        self.clean = clean
 
     def run(self, image):
         image.cutouts_idxs, image.cutouts = cutouts(image.data, image.stars_coords, size=self.size)
+        if self.clean:
+            if hasattr(image, "stars_coords"):
+                image.stars_coords = image.stars_coords[image.cutouts_idxs]
+            image.cutouts = [image.cutouts[i] for i in image.cutouts_idxs]
+            image.cutouts_idxs = np.arange(len(image.cutouts))
 
 class MedianPSF(Block):
     """Get median psf from image.
@@ -138,7 +145,7 @@ class MedianPSF(Block):
     cutout_size : int, optional
         size of the cutouts used to compute the global PSF, by default None which mean the Image.cutouts are used
     """
-    @register_args
+    
     def __init__(self, cutout_size=None, stars=None, n=None, **kwargs):
         super().__init__(**kwargs)
         self.cutout_block = None
@@ -220,7 +227,7 @@ class FWHM(PSFModel):
     (based on Arielle Bertrou-Cantou's idea)
     """
     
-    @register_args
+    
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
@@ -267,7 +274,7 @@ class FastGaussian(PSFModel):
     """
     Fit a symetric 2D Gaussian model to an image effective PSF
     """
-    @register_args
+    
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
@@ -391,7 +398,7 @@ class Gaussian2D(PSFModel):
 
     """
 
-    @register_args
+    
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
@@ -523,7 +530,7 @@ class Moffat2D(PSFModel):
 
     """
 
-    @register_args
+    
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
@@ -570,7 +577,7 @@ class Moffat2D(PSFModel):
 
 class KeepGoodStars(Block):
 
-    @register_args
+    
     def __init__(self, stat=0, n=-1, **kwargs):
         super().__init__(**kwargs)
         self.n = n
