@@ -20,9 +20,36 @@ import matplotlib.patches as patches
 from ..image import Image
 from astropy.nddata import Cutout2D as astopy_Cutout2D
 from astropy.units.quantity import Quantity
+from astropy.stats import sigma_clipped_stats
 
+__all__ = [
+    "Stack",
+    "StackStd",
+    "SaveReduced",
+    "RemoveBackground",
+    "CleanCosmics",
+    "Pass",
+    "ImageBuffer",
+    "Set",
+    "Flip",
+    "Get",
+    "XArray",
+    "LocalInterpolation",
+    "Trim",
+    "Calibration",
+    "CleanBadPixels",
+    "MedianStack",
+    "XArray2",
+    "MPCalibration",
+    "Del"
+]
 
-class Stack(Block):
+class DataBlock(Block):
+
+    def __init__(self, name=None):
+        super().__init__(name)
+
+class Stack(DataBlock):
     """Build a FITS stack image of the observation
 
     The stack image is accessible through the ``stack`` attribute. It is built by accumulating images along creating a pixel weights map. This map allows to ignore bad pixels contributions to the stack, built through a weighted mean.
@@ -42,7 +69,7 @@ class Stack(Block):
     overwrite : bool, optional
         weather to overwrite file if exists, by default False
     """
-    @register_args
+    
     def __init__(self, ref=None, **kwargs):
 
         super(Stack, self).__init__(**kwargs)
@@ -90,9 +117,9 @@ class Stack(Block):
             self._stack = block._stack
         self._n_images += block._n_images
 
-class StackStd(Block):
+class StackStd(DataBlock):
+    
     
-    @register_args
     def __init__(self, destination=None, overwrite=False, **kwargs):
         super(StackStd, self).__init__(**kwargs)
         self.images = []
@@ -127,7 +154,7 @@ class SaveReduced(Block):
         weather to overwrite file if exists, by default False
     """
     # TODO rename to SaveFITS and make destination a string like thing with the name of the image...
-    @register_args
+    
     def __init__(self, destination, overwrite=False, **kwargs):
 
         super().__init__(**kwargs)
@@ -158,60 +185,9 @@ class SaveReduced(Block):
     def concat(self, block):
         self.files = [*self.files, *block.files]
 
-# TODO remove and replace in Calibration pipeline
-class _Video(Block):
-    """Build a video of all :code:`Image.data`.
-
-    Can be either from raw image or a :code:`int8` rgb image.
-
-    Parameters
-    ----------
-    destination : str
-        path of the video which format depends on the extension (e.g. :code:`.mp4`, or :code:`.gif)
-    overwrite : bool, optional
-        weather to overwrite file if exists, by default False
-    factor : float, optional
-        subsampling factor of the image, by default 0.25
-    fps : int, optional
-        frames per second of the video, by default 10
-    from_fits : bool, optional
-        Wether :code:`Image.data` is a raw fits image, by default False. If True, a z scaling is applied as well as casting to `uint8`
-    """
-    @register_args
-    def __init__(self, destination, overwrite=True, factor=0.25, fps=10, from_fits=False, **kwargs):
-
-        super().__init__(**kwargs)
-        self.destination = destination
-        self.overwrite = overwrite
-        self.images = []
-        self.factor = factor
-        self.fps = fps
-        self.from_fits = from_fits
-        self.checked_writer = False
-        
-    def run(self, image):
-        if not self.checked_writer:
-            _ = imageio.get_writer(self.destination, mode="I")
-            self.checked_writer = True
-
-        if self.from_fits:
-            self.images.append(viz.gif_image_array(image.data, factor=self.factor))
-        else:
-            self.images.append(image.data.copy())
-
-    def terminate(self):
-        imageio.mimsave(self.destination, self.images, fps=self.fps)
-
-    def citations(self):
-        return "imageio"
-
-
-from astropy.stats import sigma_clipped_stats
-
-
 class RemoveBackground(Block):
 
-    @register_args
+    
     def __init__(self):
         super().__init__()
         self.stack_data = None
@@ -223,7 +199,7 @@ class RemoveBackground(Block):
 
 class CleanCosmics(Block):
 
-    @register_args
+    
     def __init__(self, threshold=2):
         super().__init__()
         self.stack_data = None
@@ -243,7 +219,7 @@ class CleanCosmics(Block):
 
 class Pass(Block):
     """A Block that does nothing"""
-    @register_args
+    
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
     
@@ -251,10 +227,10 @@ class Pass(Block):
         pass
 
 
-class ImageBuffer(Block):
+class ImageBuffer(DataBlock):
     """Stores the last Image
     """
-    @register_args
+    
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         self.image = None
@@ -279,7 +255,7 @@ class Set(Block):
     kwargs : kwargs
         keywords argument and values to be set on every image
     """
-    @register_args
+    
     def __init__(self, name=None, **kwargs):
         super().__init__(name=name)
         self.kwargs = kwargs
@@ -297,7 +273,7 @@ class Flip(Block):
     reference_image : `Image`
         Image serving as a reference for the flip value
     """
-    @register_args
+    
     def __init__(self, reference_image, **kwargs):
         """[summary]
 
@@ -317,24 +293,31 @@ class Flip(Block):
             image.data = image.data[::-1, ::-1]
 
 # TODO document
-class Get(Block):
+class Get(DataBlock):
 
-    @register_args
-    def __init__(self, *names):
-        super().__init__()
+    
+    def __init__(self, *names, name="get"):
+        super().__init__(name=name)
         self.names = names
         self.values = {name: [] for name in names}
 
     def run(self, image, **kwargs):
         for name in self.names:
-            if name in image.__dict__:
-                value = image.__dict__[name]
-            elif name in image.header:
-                value = image.header[name]
-            else:
-                raise AttributeError(f"'{name}' not in Image attributes or Image.header")
+            try:
+                value = image.__getattribute__(name)
+            except:
+                try:
+                    value = image.header[name]
+                except:
+                    raise AttributeError(f"'{name}' not in Image attributes or Image.header")
 
             self.values[name].append(value)
+    
+    def __getattr__(self, key):
+        if key in self.names:
+            return self.values[key]
+        else:
+            super().__getattribute__(key)
 
 
     def __call__(self, *names):
@@ -346,12 +329,12 @@ class Get(Block):
             return [self.values[name] for name in names]
 
     def concat(self, block):
-        for name in self.values.keys():
+        for name in self.names:
             self.values[name] = [*self.values[name], *block.values[name]]
 
-class XArray(Block):
+class XArray(DataBlock):
 
-    @register_args
+    
     def __init__(self, *names, name="xarray", raise_error=True, concat_dim="time", **kwargs):
         super().__init__(name=name)
         self.variables = {name: (dims, []) for dims, name in names}
@@ -396,6 +379,16 @@ class XArray(Block):
         else:
             self.variables = block.variables.copy()
 
+    def to_observation(self, stack, sequence=None):
+        xarr = utils.image_in_xarray(stack, self.xarray, stars=True) # adding reference as a stack
+        xarr = xarr.transpose("apertures", "star", "time", ...) # ... just needed
+
+        if sequence is not None:
+            xarr.attrs["photometry"] = [b.__class__.__name__ for b in sequence.blocks]
+
+        # xarr.attrs["prose_version"] = __version__
+        return xarr
+
 class LocalInterpolation(Block):
     
     def __init__(self, **kargs):
@@ -472,7 +465,7 @@ class Trim(Block):
 
     """
 
-    @register_args
+    
     def __init__(self, skip_wcs=False, trim=None, **kwargs):
 
         super().__init__(**kwargs)
@@ -513,7 +506,7 @@ class Calibration(Block):
         list of bias files paths
     """
 
-    @register_args
+    
     def __init__(self, darks=None, flats=None, bias=None, loader=Image, easy_ram=True, **kwargs):
 
         super().__init__(**kwargs)
@@ -531,7 +524,7 @@ class Calibration(Block):
 
     def _produce_master(self, images, image_type):
         if images is not None:
-            assert isinstance(images, (list, np.array)), "images must be list or array"
+            assert isinstance(images, (list, np.ndarray)), "images must be list or array"
             if len(images) == 0:
                 images = None
 
@@ -690,7 +683,7 @@ class CleanBadPixels(Block):
         image.data = self.clean(image.data.copy())
 
 
-class MedianStack(Block):
+class MedianStack(DataBlock):
     
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
@@ -703,7 +696,7 @@ class MedianStack(Block):
         self.stack = Image(data=np.median(self.images, 0))
 
 
-class XArray2(Block):
+class XArray2(DataBlock):
     def __init__(self, names, name="xarray", raise_error=True, concat_dim="time", **kwargs):
         super().__init__(name=name)
         self.variables = names
