@@ -9,6 +9,7 @@ from dateutil import parser as dparser
 from astropy.wcs import WCS
 from . import viz, utils, Telescope
 from .utils import gaia_query
+from functools import partial
 
 from astropy.io import fits
 from datetime import timedelta
@@ -552,4 +553,8 @@ class Image:
         if ax is None:
             ax = plt.gca()
             
-        viz.plot_marks(*stars_coords.T, label=label, ax=ax, **kwargs)
\ No newline at end of file
+        viz.plot_marks(*stars_coords.T, label=label, ax=ax, **kwargs)
+
+    @classmethod
+    def from_telescope(cls, telescope):
+        return partial(cls, telescope=telescope)
\ No newline at end of file
