@@ -1,10 +1,7 @@
 import numpy as np
-import pandas as pd
-import collections
 import matplotlib.pyplot as plt
-from ..utils import fast_binning, z_scale
-from ..console_utils import INFO_LABEL
 from .. import Observation
+from ..tess import TFOPObservation
 import os
 from os import path
 from astropy.time import Time
@@ -13,9 +10,12 @@ from .core import LatexTemplate
 import astropy.units as u
 
 
-class Summary(Observation, LatexTemplate):
-    def __init__(self, obs, style="paper", template_name="summary.tex"):
-        Observation.__init__(self, obs.xarray)
+class Summary(TFOPObservation, Observation, LatexTemplate):
+    def __init__(self, photfile, name=None, style="paper", template_name="summary.tex",tess=False):
+        if tess is True :
+            TFOPObservation.__init__(self, photfile,name=name)
+        else :
+            Observation.__init__(self,photfile)
         LatexTemplate.__init__(self, template_name, style=style)
 
         datetimes = Time(self.time, format='jd', scale='utc').to_datetime()
@@ -25,31 +25,31 @@ class Summary(Observation, LatexTemplate):
         obs_duration_hours = (max_datetime - min_datetime).seconds // 3600
         obs_duration_mins = ((max_datetime - min_datetime).seconds // 60) % 60
 
-        obs_duration = f"{min_datetime.strftime('%H:%M')} - {max_datetime.strftime('%H:%M')} " \
+        self.obs_duration = f"{min_datetime.strftime('%H:%M')} - {max_datetime.strftime('%H:%M')} " \
             f"[{obs_duration_hours}h{obs_duration_mins if obs_duration_mins != 0 else ''}]"
 
         # TODO: adapt to use PSF model block here (se we don't use the plot_... method from Observation)
 
-        mean_fwhm = np.mean(self.x.fwhm.values)
+        self.mean_fwhm = np.mean(self.x.fwhm.values)
         self._compute_psf_model(star=self.target)
-        mean_target_fwhm = np.mean([self.stack.fwhmx, self.stack.fwhmy])
-        optimal_aperture = np.mean(self.apertures_radii[self.aperture,:])
+        self.mean_target_fwhm = np.mean([self.stack.fwhmx, self.stack.fwhmy])
+        self.optimal_aperture = np.mean(self.apertures_radii[self.aperture,:])
 
         self.obstable = [
-            ["Time", obs_duration],
+            ["Time", self.obs_duration],
             ["RA - DEC", f"{self.RA} {self.DEC}"],
             ["Images", len(self.time)],
             ["Mean std · fwhm (epsf)",
-             f"{mean_fwhm / (2 * np.sqrt(2 * np.log(2))):.2f} · {mean_fwhm:.2f} pixels"],
-            ["Fwhm (target)", f"{mean_target_fwhm:.2f} pixels · {(mean_target_fwhm*self.telescope.pixel_scale.to(u.arcsec)):.2f}"],
-            ["Optimum aperture", f"{optimal_aperture:.2f} pixels · "
-                                 f"{(optimal_aperture*self.telescope.pixel_scale.to(u.arcsec)):.2f}"],
+             f"{self.mean_fwhm / (2 * np.sqrt(2 * np.log(2))):.2f} · {self.mean_fwhm:.2f} pixels"],
+            ["Fwhm (target)", f"{self.mean_target_fwhm:.2f} pixels · {(self.mean_target_fwhm*self.telescope.pixel_scale.to(u.arcsec)):.2f}"],
+            ["Optimum aperture", f"{self.optimal_aperture:.2f} pixels · "
+                                 f"{(self.optimal_aperture*self.telescope.pixel_scale.to(u.arcsec)):.2f}"],
             ["Telescope", self.telescope.name],
             ["Filter", self.filter],
             ["Exposure", f"{np.mean(self.exptime)} s"],
         ]
 
-        self.description = f"{self.date.strftime('%Y %m %d')} $\cdot$ {self.telescope.name} $\cdot$ {self.filter}"
+        self.description = f"{self.night_date.strftime('%Y %m %d')} $\cdot$ {self.telescope.name} $\cdot$ {self.filter}"
         self._trend = None
         self._transit = None
         self.dpi = 100
@@ -170,58 +170,3 @@ class Summary(Observation, LatexTemplate):
         os.chdir(self.destination)
         os.system(f"pdflatex {self.report_name}")
         os.chdir(cwd)
-
-
-class TESSSummary(Summary):
-
-    def __init__(self, obs, style="paper", expected=None, template_name="summary.tex"):
-        Summary.__init__(self, obs, style=style, template_name=template_name)
-        self.obstable.insert(0, ("TIC id", self.tic_id))
-        self.obstable.insert(4, ("GAIA id", self.gaia_from_toi))
-        self.header = "TESS follow-up"
-        self.expected = expected
-
-    def to_csv_report(self):
-        """Export a typical csv of the observation's data
-        """
-        destination = path.join(self.destination, "..", "measurements.txt")
-
-        comparison_stars = self.comps[self.aperture]
-        list_diff = ["DIFF_FLUX_C%s" % i for i in comparison_stars]
-        list_err = ["DIFF_ERROR_C%s" % i for i in comparison_stars]
-        list_columns = [None] * (len(list_diff) + len(list_err))
-        list_columns[::2] = list_diff
-        list_columns[1::2] = list_err
-        list_diff_array = [self.diff_fluxes[self.aperture, i] for i in comparison_stars]
-        list_err_array = [self.diff_errors[self.aperture, i] for i in comparison_stars]
-        list_columns_array = [None] * (len(list_diff_array) + len(list_err_array))
-        list_columns_array[::2] = list_diff_array
-        list_columns_array[1::2] = list_err_array
-
-        df = pd.DataFrame(collections.OrderedDict(
-            {
-                "BJD-TDB" if self.time_format == "bjd_tdb" else "JD-UTC": self.time,
-                "DIFF_FLUX_T%s" % self.target : self.diff_flux,
-                "DIFF_ERROR_T%s" % self.target: self.diff_error,
-                **dict(zip(list_columns, list_columns_array)),
-                "dx": self.dx,
-                "dy": self.dy,
-                "FWHM": self.fwhm,
-                "SKYLEVEL": self.sky,
-                "AIRMASS": self.airmass,
-                "EXPOSURE": self.exptime,
-            })
-        )
-        df.to_csv(destination, sep="\t", index=False)
-
-    def make(self, destination):
-        super().make(destination)
-        self.to_csv_report()
-
-    def plot_lc(self):
-        super().plot_lc()
-        if self.expected is not None:
-            t0, duration = self.expected
-            std = 2 * np.std(self.diff_flux)
-            viz.plot_section(1 + std, "expected transit", t0, duration, c="k")
-
