@@ -179,12 +179,12 @@ class Telescope:
             return telescope
 
     @staticmethod
-    def from_names(instrument_name, telescope_name):
+    def from_names(instrument_name, telescope_name, verbose=True):
         # we first check by instrument name
         telescope = Telescope.from_name(instrument_name, strict=True, verbose=False)
         # if not found we check telescope name
         if telescope is None:
-            telescope = Telescope.from_name(telescope_name)
+            telescope = Telescope.from_name(telescope_name, verbose=verbose)
         
         return telescope
 
